@@ -1,4 +1,4 @@
-from django.forms import DateInput, MultiWidget, SplitDateTimeWidget, TimeInput
+from django.forms import DateInput, MultiWidget, TimeInput
 from django.forms.utils import to_current_timezone
 from django.forms.widgets import Input
 
@@ -15,10 +15,6 @@ class CustomTimeInput(TimeInput):
     template_name = "extra/widgets/custom_time_input.html"
 
 
-class CustomSplitDateTimeInput(SplitDateTimeWidget):
-    pass
-
-
 class CustomSplitDateTimeWidget(MultiWidget):
     """
     A widget that splits datetime input into two <input type="text"> boxes.
